@@ -1,6 +1,6 @@
 package Net::Amazon::S3::Client::Object;
 {
-  $Net::Amazon::S3::Client::Object::VERSION = '0.57';
+  $Net::Amazon::S3::Client::Object::VERSION = '0.58';
 }
 use Moose 0.85;
 use MooseX::StrictConstructor 0.16;
@@ -77,18 +77,15 @@ sub get {
     my $content       = $http_response->content;
 
     my $md5_hex = md5_hex($content);
+    my $etag = $self->etag || $self->_etag($http_response);
+    confess 'Corrupted download'
+      if( !$self->_is_multipart_etag($etag) && $etag ne $md5_hex);
 
-    if ( $self->etag ) {
-        confess 'Corrupted download' if $self->etag ne $md5_hex;
-    } else {
-        confess 'Corrupted download'
-            if $self->_etag($http_response) ne $md5_hex;
-    }
     return $content;
 }
 
 sub get_filename {
-    my ( $self, $filename ) = @_;
+    my ($self, $filename) = @_;
 
     my $http_request = Net::Amazon::S3::Request::GetObject->new(
         s3     => $self->client->s3,
@@ -98,16 +95,13 @@ sub get_filename {
     )->http_request;
 
     my $http_response
-        = $self->client->_send_request( $http_request, $filename );
+        = $self->client->_send_request($http_request, $filename);
 
     my $md5_hex = file_md5_hex($filename);
 
-    if ( $self->etag ) {
-        confess 'Corrupted download' if $self->etag ne $md5_hex;
-    } else {
-        confess 'Corrupted download'
-            if $self->_etag($http_response) ne $md5_hex;
-    }
+    my $etag = $self->etag || $self->_etag($http_response);
+    confess
+      'Corrupted download' if(!$self->_is_multipart_etag($etag) && $etag ne $md5_hex);
 }
 
 sub put {
@@ -213,6 +207,60 @@ sub delete {
     $self->client->_send_request($http_request);
 }
 
+sub initiate_multipart_upload {
+    my $self = shift;
+    my $http_request = Net::Amazon::S3::Request::InitiateMultipartUpload->new(
+        s3     => $self->client->s3,
+        bucket => $self->bucket->name,
+        key    => $self->key,
+    )->http_request;
+    my $xpc = $self->client->_send_request_xpc($http_request);
+    my $upload_id = $xpc->findvalue('//s3:UploadId');
+    confess "Couldn't get upload id from initiate_multipart_upload response XML"
+      unless $upload_id;
+
+    return $upload_id;
+}
+
+sub complete_multipart_upload {
+    my $self = shift;
+
+    my %args = ref($_[0]) ? %{$_[0]} : @_;
+
+    #set default args
+    $args{s3}       = $self->client->s3;
+    $args{key}      = $self->key;
+    $args{bucket}   = $self->bucket->name;
+
+    my $http_request =
+      Net::Amazon::S3::Request::CompleteMultipartUpload->new(%args)->http_request;
+    return $self->client->_send_request($http_request);
+}
+
+sub put_part {
+    my $self = shift;
+
+    my %args = ref($_[0]) ? %{$_[0]} : @_;
+
+    #set default args
+    $args{s3}       = $self->client->s3;
+    $args{key}      = $self->key;
+    $args{bucket}   = $self->bucket->name;
+    #work out content length header
+    $args{headers}->{'Content-Length'} = length $args{value}
+      if(defined $args{value});
+
+    my $http_request =
+      Net::Amazon::S3::Request::PutPart->new(%args)->http_request;
+    return $self->client->_send_request($http_request);
+}
+
+sub list_parts {
+    confess "Not implemented";
+    # TODO - Net::Amazon::S3::Request:ListParts is implemented, but need to
+    # define better interface at this level. Currently returns raw XML.
+}
+
 sub uri {
     my $self = shift;
     return Net::Amazon::S3::Request::GetObject->new(
@@ -286,6 +334,11 @@ sub _etag {
     return $etag;
 }
 
+sub _is_multipart_etag {
+    my ( $self, $etag ) = @_;
+    return 1 if($etag =~ /\-\d+$/);
+}
+
 1;
 
 __END__
@@ -298,7 +351,7 @@ Net::Amazon::S3::Client::Object - An easy-to-use Amazon S3 client object
 
 =head1 VERSION
 
-version 0.57
+version 0.58
 
 =head1 SYNOPSIS
 
@@ -465,6 +518,39 @@ Content-Disposition using content_disposition.
   # return the URI of a publically-accessible object
   my $uri = $object->uri;
 
+=head2 initiate_multipart_upload
+
+  #initiate a new multipart upload for this object
+  my $object = $bucket->object(
+    key         => 'massive_video.avi'
+  );
+  my $upload_id = $object->initiate_multipart_upload;
+
+=head2 put_part
+
+  #add a part to a multipart upload
+  my $put_part_response = $object->put_part(
+     upload_id      => $upload_id,
+     part_number    => 1,
+     value          => $chunk_content,
+  );
+  my $part_etag = $put_part_response->header('ETag')
+
+  Returns an L<HTTP::Response> object. It is necessary to keep the ETags for
+  each part, as these are required to complete the upload.
+
+=head2 complete_multipart_upload
+
+  #complete a multipart upload
+  $object->complete_multipart_upload(
+    upload_id       => $upload_id,
+    etags           => [$etag_1, $etag_2],
+    part_numbers    => [$part_number_1, $part_number2],
+  );
+
+  The etag and part_numbers parameters are ordered lists specifying the part
+  numbers and ETags for each individual part of the multipart upload.
+
 =head1 AUTHOR
 
 Pedro Figueiredo <me@pedrofigueiredo.org>
